From: Dave Zarzycki Date: Mon, 06 Feb 2012 09:07:26 GMT Subject: Re: [PATCH 6/6] Automatically switch to crc32 checksum for index when it's too large Message-ID: <8A80E303-311E-4B87-A4B4-4F39AA932956@apple.com> In-Reply-To: On Feb 6, 2012, at 12:54 AM, Nguyen Thai Ngoc Duy wrote: > 2012/2/6 Dave Zarzycki : >> Which crc32 polynomial is being used? crc32c (a.k.a. Castagnoli)? It would be great if this were the same polynomial that Intel implements in hardware via SSE4.2. > > It's zlib's crc32. That's too bad. Zlib uses crc32, not crc32c. The Intel instruction is crc32c and is 2-3 times faster than the best software based implementation. http://www.strchr.com/crc32_popcnt > >> On Feb 5, 2012, at 9:48 PM, Nguyễn Thái Ngọc Duy wrote: >> >>> An experiment with -O3 is done on Intel D510@1.66GHz. At around 250k >>> entries, index reading time exceeds 0.5s. Switching to crc32 brings it >>> back lower than 0.2s. >>> >>> On 4M files index, reading time with SHA-1 takes ~8.4, crc32 2.8s. > -- > Duy > -- > To unsubscribe from this list: send the line "unsubscribe git" in > the body of a message to majordomo@vger.kernel.org > More majordomo info at http://vger.kernel.org/majordomo-info.html